package com.ff.game.service.impl;

import java.util.List;
import com.ff.base.utils.DateUtils;
import com.ff.common.domain.TenantSecretKey;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ff.game.mapper.GameSecretKeyMapper;
import com.ff.game.domain.GameSecretKey;
import com.ff.game.service.IGameSecretKeyService;

/**
 * 游戏平台密钥管理Service业务层处理
 *
 * @author shi
 * @date 2025-02-10
 */
@Service
public class GameSecretKeyServiceImpl implements IGameSecretKeyService
{
    @Autowired
    private GameSecretKeyMapper gameSecretKeyMapper;

    /**
     * 查询游戏平台密钥管理
     *
     * @param id 游戏平台密钥管理主键
     * @return 游戏平台密钥管理
     */
    @Override
    public GameSecretKey selectGameSecretKeyById(Long id)
    {
        return gameSecretKeyMapper.selectGameSecretKeyById(id);
    }

    /**
     * 查询游戏平台密钥管理列表
     *
     * @param gameSecretKey 游戏平台密钥管理
     * @return 游戏平台密钥管理
     */
    @Override
    public List<GameSecretKey> selectGameSecretKeyList(GameSecretKey gameSecretKey)
    {
        return gameSecretKeyMapper.selectGameSecretKeyList(gameSecretKey);
    }

    /**
     * 新增游戏平台密钥管理
     *
     * @param gameSecretKey 游戏平台密钥管理
     * @return 结果
     */
    @Override
    public int insertGameSecretKey(GameSecretKey gameSecretKey)
    {
        gameSecretKey.setCreateTime(DateUtils.getNowDate());
        return gameSecretKeyMapper.insertGameSecretKey(gameSecretKey);
    }

    /**
     * 修改游戏平台密钥管理
     *
     * @param gameSecretKey 游戏平台密钥管理
     * @return 结果
     */
    @Override
    public int updateGameSecretKey(GameSecretKey gameSecretKey)
    {
        gameSecretKey.setUpdateTime(DateUtils.getNowDate());
        return gameSecretKeyMapper.updateGameSecretKey(gameSecretKey);
    }

    /**
     * 批量删除游戏平台密钥管理
     *
     * @param ids 需要删除的游戏平台密钥管理主键
     * @return 结果
     */
    @Override
    public int deleteGameSecretKeyByIds(Long[] ids)
    {
        return gameSecretKeyMapper.deleteGameSecretKeyByIds(ids);
    }

    /**
     * 删除游戏平台密钥管理信息
     *
     * @param id 游戏平台密钥管理主键
     * @return 结果
     */
    @Override
    public int deleteGameSecretKeyById(Long id)
    {
        return gameSecretKeyMapper.deleteGameSecretKeyById(id);
    }


    /**
     * 按代码查找系统
     *
     * @param code     代码
     * @param platform 平台
     * @return {@link String }
     */
    @Override
    public String findSystemByCode(String code,String platform) {
        return gameSecretKeyMapper.findSystemByCode(code,platform);
    }

    /**
     * 通过平台和系统代码查找密钥
     *
     * @param platform   平台
     * @param systemCode 系统代码
     * @return {@link GameSecretKey }
     */
    @Override
    public GameSecretKey findSecretKeyByPlatformAndSystemCode(String platform, String systemCode) {
        return gameSecretKeyMapper.findSecretKeyByPlatformAndSystemCode(platform,systemCode);
    }

    /**
     * 按平台和系统查找lang代码
     *
     * @param platform       平台
     * @param systemLangCode 系统语言代码
     * @return {@link GameSecretKey }
     */
    @Override
    public GameSecretKey findByPlatformAndSystemLangCode(String platform, String systemLangCode) {
        return gameSecretKeyMapper.findByPlatformAndSystemLangCode(platform,systemLangCode);
    }
}
